* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Code-Based Automations](https://help.sap.com/docs/leanix/ea/code-based-automations)
  * Managing Fact Sheet Tags Dynamically Based on Relat…
